@@ -18,16 +18,13 @@
  */
 
 /**
- * <b>Tobago Framework Component Tag Library 4.6.0 -
- * (C) Copyright 2005-2022 The Apache Software Foundation</b>
+ * <b>Tobago Framework Component Tag Library 5.2.0 -
+ * (C) Copyright 2005-2021 The Apache Software Foundation</b>
  */
 @org.apache.myfaces.tobago.apt.annotation.Taglib(
     shortName = "tc",
     uri = "http://myfaces.apache.org/tobago/component",
-    listener = {
-        "org.apache.myfaces.tobago.webapp.TobagoServletContextListener",
-        "org.apache.myfaces.tobago.webapp.SecretSessionListener"},
     name = "tobago",
-    displayName = "Tobago Components 4.6.0")
+    displayName = "Tobago Components 5.2.0")
 
 package org.apache.myfaces.tobago.internal.taglib.component;
